how_long
========

Simple Decorator to measure a function execution time.

Example
_______

.. code-block:: python

    from longhow import timer


    @timer
    def some_function():
        return [x for x in range(10_000_000)]